==> openshift-model-console-6.7.1-sources.jar: io/fabric8/openshift/api/model/console/v1alpha1/ConsolePluginBuilder.java <==
package io.fabric8.openshift.api.model.console.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ConsolePluginBuilder extends ConsolePluginFluentImpl<ConsolePluginBuilder> implements VisitableBuilder<ConsolePlugin,ConsolePluginBuilder>{
  public ConsolePluginBuilder() {
    this(false);
  }
  public ConsolePluginBuilder(Boolean validationEnabled) {
    this(new ConsolePlugin(), validationEnabled);
  }
  public ConsolePluginBuilder(ConsolePluginFluent<?> fluent) {
    this(fluent, false);
  }
  public ConsolePluginBuilder(ConsolePluginFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ConsolePlugin(), validationEnabled);
  }
  public ConsolePluginBuilder(ConsolePluginFluent<?> fluent,ConsolePlugin instance) {
    this(fluent, instance, false);
  }
  public ConsolePluginBuilder(ConsolePluginFluent<?> fluent,ConsolePlugin instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ConsolePluginBuilder(ConsolePlugin instance) {
    this(instance,false);
  }
  public ConsolePluginBuilder(ConsolePlugin instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ConsolePluginFluent<?> fluent;
  Boolean validationEnabled;
  public ConsolePlugin build() {
    ConsolePlugin buildable = new ConsolePlugin(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-console-6.8.0-sources.jar: io/fabric8/openshift/api/model/console/v1alpha1/ConsolePluginBuilder.java <==
package io.fabric8.openshift.api.model.console.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ConsolePluginBuilder extends ConsolePluginFluent<ConsolePluginBuilder> implements VisitableBuilder<ConsolePlugin,ConsolePluginBuilder>{
  public ConsolePluginBuilder() {
    this(false);
  }
  public ConsolePluginBuilder(Boolean validationEnabled) {
    this(new ConsolePlugin(), validationEnabled);
  }
  public ConsolePluginBuilder(ConsolePluginFluent<?> fluent) {
    this(fluent, false);
  }
  public ConsolePluginBuilder(ConsolePluginFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ConsolePlugin(), validationEnabled);
  }
  public ConsolePluginBuilder(ConsolePluginFluent<?> fluent,ConsolePlugin instance) {
    this(fluent, instance, false);
  }
  public ConsolePluginBuilder(ConsolePluginFluent<?> fluent,ConsolePlugin instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ConsolePlugin());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withKind(instance.getKind());
      fluent.withMetadata(instance.getMetadata());
      fluent.withSpec(instance.getSpec());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ConsolePluginBuilder(ConsolePlugin instance) {
    this(instance,false);
  }
  public ConsolePluginBuilder(ConsolePlugin instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ConsolePlugin());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ConsolePluginFluent<?> fluent;
  Boolean validationEnabled;
  public ConsolePlugin build() {
    ConsolePlugin buildable = new ConsolePlugin(fluent.getApiVersion(),fluent.getKind(),fluent.buildMetadata(),fluent.buildSpec());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
